nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Usbhsh

Struct Usbhsh 

pub struct Usbhsh { /* private fields */ }
USB1 High-speed Host Controller

Implementations

Source

impl Usbhsh

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn caplength_chipid(self) -> Reg<CaplengthChipid, R>

This register contains the offset value towards the start of the operational register space and the version number of the IP block

pub const fn hcsparams(self) -> Reg<Hcsparams, R>

Host Controller Structural Parameters

pub const fn fladj_frindex(self) -> Reg<FladjFrindex, RW>

Frame Length Adjustment

pub const fn atlptd(self) -> Reg<Atlptd, RW>

Memory base address where ATL PTD0 is stored

pub const fn isoptd(self) -> Reg<Isoptd, RW>

Memory base address where ISO PTD0 is stored

pub const fn intptd(self) -> Reg<Intptd, RW>

Memory base address where INT PTD0 is stored

pub const fn datapayload(self) -> Reg<Datapayload, RW>

Memory base address that indicates the start of the data payload buffers

pub const fn usbcmd(self) -> Reg<Usbcmd, RW>

USB Command register

pub const fn usbsts(self) -> Reg<Usbsts, RW>

USB Interrupt Status register

pub const fn usbintr(self) -> Reg<Usbintr, RW>

USB Interrupt Enable register

pub const fn portsc1(self) -> Reg<Portsc1, RW>

Port Status and Control register

pub const fn atlptdd(self) -> Reg<Atlptdd, RW>

Done map for each ATL PTD

pub const fn atlptds(self) -> Reg<Atlptds, RW>

Skip map for each ATL PTD

pub const fn isoptdd(self) -> Reg<Isoptdd, RW>

Done map for each ISO PTD

pub const fn isoptds(self) -> Reg<Isoptds, RW>

Skip map for each ISO PTD

pub const fn intptdd(self) -> Reg<Intptdd, RW>

Done map for each INT PTD

pub const fn intptds(self) -> Reg<Intptds, RW>

Skip map for each INT PTD

pub const fn lastptd(self) -> Reg<Lastptd, RW>

Marks the last PTD in the list for ISO, INT and ATL

pub const fn portmode(self) -> Reg<Portmode, RW>

Controls the port if it is attached to the host block or the device block